@@ -1,8 +1,14 @@
 ## File Name: files_move.R
-## File Version: 0.19
+## File Version: 0.27
 
-files_move <- function( path1, path2, file_sep="__", pattern=NULL)
+files_move <- function( path1, path2, file_sep="__", pattern=NULL,
+    path2_name="__ARCH")
 {
+    #*** include missing path2 argument
+    if ( missing(path2) ){
+        f1 <- list.files(path1, path2_name)
+        path2 <- file.path(path1, f1)
+    }
 
     #*** search for all relevant files
     files <- list.files( path1, "\\."  )
@@ -11,7 +17,7 @@ files_move <- function( path1, path2, file_sep="__", pattern=NULL)
     }
     #*** create file overview
     NF <- length(files)
-    if (NF > 0 ){
+    if (NF > 1){
         matr <- matrix( NA, nrow=NF, ncol=5)
         for (ff in 1:NF){
             file_ff <- files[ff]
@@ -21,7 +27,6 @@ files_move <- function( path1, path2, file_sep="__", pattern=NULL)
         matr <- as.data.frame(matr)
         colnames(matr) <- names(res_ff)
         matr$main_id <- match( matr$main, unique( matr$main) )
-
         matr <- matr[ order( matr$main ), ]
         matr$eq <- c(0,matr$main[ - NF ] !=matr$main[-1])
         t1 <- table( matr$main_id )
@@ -32,9 +37,8 @@ files_move <- function( path1, path2, file_sep="__", pattern=NULL)
                 file.rename( from=file.path( path1, matr[ff-1,"file_name"] ),
                         to=file.path( path2, matr[ff-1,"file_name"] ) )
                 cat("*** Move ", paste0(matr[ff-1,"file_name"]), "\n" )
-                utils::flush.console();
+                utils::flush.console()
             }
-
         }
     }
 }
