@@ -1,32 +1,32 @@
 ## File Name: mice.impute.2l.latentgroupmean.mcmc.R
-## File Version: 3.30
+## File Version: 3.33
+
 mice.impute.2l.latentgroupmean.mcmc <- function (y, ry, x, type,
                     pls.facs=NULL, imputationWeights=NULL,
                     interactions=NULL, quadratics=NULL,
                     mcmc.burnin=100, mcmc.adapt=100, mcmc.iter=1000,
-                      draw.fixed=TRUE, EAP=FALSE, ...)
+                    draw.fixed=TRUE, EAP=FALSE, ...)
 {
-
     TAM::require_namespace_msg("MCMCglmm")
     # retrieve mice objects
-    k <- get("k", envir=parent.frame())           # iteration
-    i <- get("i", envir=parent.frame())           # imputation
-    vname <- get("vname", envir=parent.frame())   # variable name
+    k <- ma_exists_get("k", pos=parent.frame())           # iteration
+    i <- ma_exists_get("i", pos=parent.frame())           # imputation
+    vname <- ma_exists_get("vname", pos=parent.frame())   # variable name
 
     # create list for storing state (first call)
     if( !exists("storeState.latentgroupmean.MCMC", where=parent.frame()) ){
-      assign("storeState.latentgroupmean.MCMC", list(), pos=parent.frame())
+        assign("storeState.latentgroupmean.MCMC", list(), pos=parent.frame())
     }
 
     # retrieve state for current variable/imputation
     storeState.latentgroupmean.MCMC <- get("storeState.latentgroupmean.MCMC", envir=parent.frame())
 
     if(k > 1){
-      burnin.iter <- mcmc.adapt
-      current.state <- storeState.latentgroupmean.MCMC[[vname]][[i]]
-    }else{
-      burnin.iter <- mcmc.burnin
-      current.state <- NULL
+        burnin.iter <- mcmc.adapt
+        current.state <- storeState.latentgroupmean.MCMC[[vname]][[i]]
+    } else {
+        burnin.iter <- mcmc.burnin
+        current.state <- NULL
     }
 
     # ***
@@ -45,8 +45,8 @@ mice.impute.2l.latentgroupmean.mcmc <- function (y, ry, x, type,
         # aggregate covariates
         cov2 <- cbind( cluster, covariates )
         covaggr <- mice.impute.2l.groupmean( y, ry, x=cov2,
-              type=c(-2, rep(1,ncol(covariates) ) ),
-                       grmeanwarning=FALSE )
+                        type=c(-2, rep(1,ncol(covariates) ) ),
+                        grmeanwarning=FALSE )
         colnames(covaggr) <- colnames(covariates)
         # aggregation at level 2
         covaggr.l2 <- stats::aggregate( covaggr, list( cluster ), mean )
@@ -67,7 +67,7 @@ mice.impute.2l.latentgroupmean.mcmc <- function (y, ry, x, type,
         if( ! is.null( plsout$yimp ) ){
             covaggr.l2r <- as.matrix(plsout$yimp[,-1])
             covaggr <- as.matrix( covaggr.l2r[ match( cluster, covaggr.l2[,1] ), ] )
-                }
+        }
 
         # model input
         rownames(covaggr) <- NULL # prevent warning
@@ -86,29 +86,29 @@ mice.impute.2l.latentgroupmean.mcmc <- function (y, ry, x, type,
 
     # inverse-gamma prior IG(.001,.001)
     prior <- list( R=list(V=1, nu=.002),
-                   G=list(G1=list(V=1, nu=.002)))
+                    G=list(G1=list(V=1, nu=.002)))
 
     mod <- MCMCglmm::MCMCglmm(mcmcfml, random=~cluster, data=mcmcdf, thin=1,
-             prior=prior, burnin=burnin.iter, nitt=burnin.iter + mcmc.iter,
-             start=current.state, verbose=FALSE)
+                prior=prior, burnin=burnin.iter, nitt=burnin.iter + mcmc.iter,
+                start=current.state, verbose=FALSE)
 
     # store current state in parent frame
     new.state <- list( R=mod$VCV[mcmc.iter, 2, drop=FALSE],
-                       G=mod$VCV[mcmc.iter, 1, drop=FALSE],
-                       liab=NULL, QUASI=TRUE )
+                        G=mod$VCV[mcmc.iter, 1, drop=FALSE],
+                        liab=NULL, QUASI=TRUE )
     # overwrite previous iteration state
     storeState.latentgroupmean.MCMC[[vname]][[i]] <- new.state
     assign("storeState.latentgroupmean.MCMC", storeState.latentgroupmean.MCMC, pos=parent.frame())
 
     # parameter estimates (post. draw by default, EAP otherwise)
     if (draw.fixed){
-      beta <- mod$Sol[mcmc.iter,]
-      psi2 <- mod$VCV[mcmc.iter,1]
-      sig2 <- mod$VCV[mcmc.iter,2]
+        beta <- mod$Sol[mcmc.iter,]
+        psi2 <- mod$VCV[mcmc.iter,1]
+        sig2 <- mod$VCV[mcmc.iter,2]
     } else {
-      beta <- apply(mod$Sol,2,mean)
-      psi2 <- mean(mod$VCV[,1])
-      sig2 <- mean(mod$VCV[,2])
+        beta <- apply(mod$Sol,2,mean)
+        psi2 <- mean(mod$VCV[,1])
+        sig2 <- mean(mod$VCV[,2])
     }
     modf <- stats::model.matrix(mcmcfml, data=mcmcdf) %*% beta
 
